/* --8<--8<--8<--8<--
 *
 * Copyright (C) 2007 Smithsonian Astrophysical Observatory
 *
 * This file is part of enwtsum
 *
 * enwtsum is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * -->8-->8-->8-->8-- */

#include <stdio.h>
#include <string.h>

#include <rbtree/rbtree.h>
#include <tracefct/tracefct.h>
#include <tracefct/exiterrvals.h>

#include "main.h"

int
output_node( void *nd, void *udata )
{
  FILE *fout = (FILE *) udata;
  EnWtSum *ews = (EnWtSum *) nd;

  fprintf( fout, "%f\t%d\t%f\n", ews->energy, ews->n, ews->wt );

  return 0;
}

void
output( Common *c, RBTree tree )
{
  FILE *fout;

  tf_enter( "output" );

  /* create output rdb table */
  if      ( 0 == strcmp( c->logfile, "stdout" ) )
    fout = stdout;
  else if ( 0 == strcmp( c->logfile, "stderr" ) )
    fout = stderr;
  else if ( NULL == ( fout = fopen( c->logfile, "w" ) ) )
    tf_exit( ExitERR_fopen, "unable to create %s", c->logfile );

  fputs( "energy\tn\twt\n", fout );
  fputs( "N\tN\tN\n", fout );

  rbtree_utraverse( tree, output_node, fout, LEFT_TO_RIGHT );

  fclose( fout );

  tf_leave( );
}

